#!/usr/bin/perl

use lib "/usr/local/nagios/libexec";
use utils qw($TIMEOUT %ERRORS);

use strict;

use MIME::Base64;
use HTTP::Lite;
use Getopt::Long;

Getopt::Long::Configure('bundling');

# Comprobar que estan todos los parametros
if (scalar(@ARGV)<4) {
	print "check_hwg-ste_xml.pl -H <ip> -S <sensor>.\n";
	exit($ERRORS{'UNKNOWN'});
}

my $condition = $ERRORS{'OK'};

if (($ARGV[0] ne "-H") && ($ARGV[2] ne "-S")) {
	print "check_hwg-ste_xml.pl -H <ip> -S <sensor>.\n";
        exit($ERRORS{'UNKNOWN'});

}

my $ip=$ARGV[1];
my $sensor=$ARGV[3];

my $http=new HTTP::Lite;
	
#Obtener el XML del sensor HWG

my $req=$http->request("http://$ip/values.xml");

if ($req ne "200") {
	$condition=$ERRORS{'CRITICAL'};
	print "HTTP ERROR\n";
	exit ($condition);
}

my $body=$http->body();

#Step 0: Convertir el XML en un array de linea
my @lineas=split /\n/, $body;

$http->reset();

#Step 1: Buscar la funcion JavaScript donde tenemos los datos y obtenerlos
my $linea;
my $procesar=0;
my $nombre="";
my $valor="";
my $unidades="";
my $minimo="";
my $maximo="";
my $estado="normal";

foreach $linea(@lineas) {
	#Recorrer el XML hasta encontrar el ID del sensor
	if (index($linea,"ID")>=0) {
		#Hay un ID de sensor, veamos si es el nuestro
		if (index($linea,$sensor)>0) {
			$procesar=1;
		}
	}
	if ($procesar) {
		if (index($linea,"<Name>")>=0) {
			$nombre=substr($linea,8,length($linea)-15);
		}
		if (index($linea,"<Value>")>=0) {
			$valor=substr($linea,9,length($linea)-17);
		}
		if (index($linea,"<Units>")>=0) {
			$unidades=substr($linea,9,length($linea)-17);
		}
		if (index($linea,"<Min>")>=0) {
			$minimo=substr($linea,7,length($linea)-13);
		}
		if (index($linea,"<Max>")>=0) {
			$maximo=substr($linea,7,length($linea)-13);
			$procesar=0;
		}
	}
}

if ($valor<=$minimo) {
	$estado="alarmlo";
	$condition=$ERRORS{'CRITICAL'};
}
if ($valor>=$maximo) {
	$estado="alarmhi";
	$condition=$ERRORS{'CRITICAL'};
}

print "Sensor: " . $nombre . ", State: " . $estado . ", Value: " . $valor . "| " . $nombre . "=" . $valor . ";\n";

#exit($condition);
exit;

